function analyzeVariability
    load 'variabilityData.mat' f Aeq b lb ub transitionIds
    transitionCount = length(transitionIds);
    
    % Scale factor
    scaleFactor = 1.0E5;
    lb = lb * scaleFactor;
    ub = ub * scaleFactor;
    
    [fval x sol_status] = lp(f, Aeq, b, lb, ub);
    
    objRef = fval;
    fluxesRef = x;
    
    % Optimal Analysis
    %ub(listIndexOfString(transitionIds, 'ER90000')) = objRef;
    %lb(listIndexOfString(transitionIds, 'ER90000')) = objRef;
    
    
    % Suboptimal analysis
    suboptimal_threshold = 0.500002;
    lb(listIndexOfString(transitionIds, 'ER90000')) = objRef * suboptimal_threshold;
    lb(listIndexOfString(transitionIds, 'R00086')) = lb(listIndexOfString(transitionIds, 'R00086')) * suboptimal_threshold;
    ub(listIndexOfString(transitionIds, 'ER90001')) = 0;
    lb(listIndexOfString(transitionIds, 'ER90001')) = 0;

    measurements_list = ['ER00010   '; 'ER00014   '; 'ER00017   '; 'ER00013   '; 'ER00008   '; 'ER00002   '; 'ER00003   '; 'ER00021   '; 'ER00009   '; 'ER00006   '; 'ER00007   '; 'ER00020   '; 'ER00015   '; 'ER00012   '; 'ER00004   '; 'ER00011   '; 'ER00016   '; 'ER00005   '; 'ER00000   '; 'ER00023   '];
    % Set values of known uptake rates
    for i = 1 : length(measurements_list)
        lb(listIndexOfString(transitionIds, measurements_list(i, :))) = fluxesRef(listIndexOfString(transitionIds, measurements_list(i, :)));
        ub(listIndexOfString(transitionIds, measurements_list(i, :))) = fluxesRef(listIndexOfString(transitionIds, measurements_list(i, :)));        
    end        
    
    
    fluxesMin = zeros(transitionCount);
    fluxesMax = zeros(transitionCount);               
    for i = 1 : transitionCount
        f = zeros(transitionCount);
        f(i) = 1;        
        [fval x sol_status] = lp(f, Aeq, b, lb, ub);        
        if (sol_status ~= 1)
            fluxesMax(i) = -555.555;
            fluxesMin(i) = -555.555;
            display(sprintf('%s - LP failure at Max!!!', transitionIds(i,:)));
            if (sol_status == 2)
                disp('  Warning: Solution found is possibly not optimal!');
            elseif (sol_status == 3)
                disp('  Error: Solution found is infeasible!');                
            elseif (sol_status == 4)
                disp('  Error: Status 4 - No Feasible!');
            elseif (sol_status == 5)
                disp('  Error: LP has unbounded solution!');
            elseif (sol_status == 6)    
                disp('  LP failure!!!');
            end
            continue;
        end
        fluxesMax(i) = x(i);
        f(i) = -1;
        [fval x sol_status] = lp(f, Aeq, b, lb, ub);
        if (sol_status ~= 1)
            fluxesMin(i) = -555.555;
            display(sprintf('%s - LP failure at Min!!!', transitionIds(i,:)));            
            if (sol_status == 2)
                disp('  Warning: Solution found is possibly not optimal!');
            elseif (sol_status == 3)
                disp('  Error: Solution found is infeasible!');                
            elseif (sol_status == 4)
                disp('  Error: Status 4 - No Feasible!');
            elseif (sol_status == 5)
                disp('  Error: LP has unbounded solution!');
            elseif (sol_status == 6)    
                disp('  LP failure!!!');
            end
            continue;
        end
        fluxesMin(i) = x(i);
        display(sprintf('%i - %s : %f - (%f, %f)', i, transitionIds(i,:), fluxesRef(i), fluxesMax(i), fluxesMin(i)));
    end
    
    writeFluxFile('d:/temp/fluxesRef.txt', transitionIds, fluxesRef);
    writeFluxFile('d:/temp/fluxesMax.txt', transitionIds, fluxesMax);
    writeFluxFile('d:/temp/fluxesMin.txt', transitionIds, fluxesMin);

    
end